<#import "macros_common_general_html.ftl" as com>
<@com.initializeMainVariables />
<@com.initiateRelevanceSPC relevance/>

<#assign justificationClassification = []/>

<#assign aicisStatement = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "AICIS_Statement") />

<!-- Classification and labelling information -->
<#macro classificationAndLabellingTable _subject record_index documentNode>
<#compress>
<#if !ghsRelevant??>
	<#if isComposite(_subject)>
		<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Ghs") /> 
		<#else>
		<#assign recordList = [_subject] />
	</#if>
<#else>
	<#assign recordList = _subject />
</#if>
    <#if recordList?has_content>
        <#list recordList as record>
		<#local counter = record?index + 1 />
			<#if counter?? && !ghsRelevant??>
			<b><@com.text record.name/></b>
			</#if>
				<@printClassificationSection record record_index documentNode/>
				<!-- Labelling section -->
				<@printLabellingSection record/>
        </#list><#else>
    </#if>
</#compress>
</#macro>

<!-- Macros and functions -->
<#macro printClassificationSection record record_index documentNode>
<#compress>

    <#if csrRelevant?? || pppRelevant?? || !ghsRelevant??>
		<p>
            <br/>

			<b>
				<u><#if pppRelevant?? && (recordList?size>1)>#${record_index+1} - </#if>
					Substance: <@classificationSubstanceName record _subject/></u>
			</b>
		</p>

		<p>
			<b>Implementation:</b> <@com.picklist record.GeneralInformation.Implementation/>
		</p>

        <#if pppRelevant?? && record.GeneralInformation.TypeClassification?has_content>
			<p>
				<b>Type of classification:</b> <@com.picklist record.GeneralInformation.TypeClassification/>
			</p>
        </#if>

        <#if !ghsRelevant??>
            <#if record.GeneralInformation.Remarks?has_content>
				<p>
					<b>Remarks:</b> <@com.richText record.GeneralInformation.Remarks/>
				</p>
            </#if>
        </#if>

        <#if record.GeneralInformation.RelatedCompositions.Composition?has_content>
			<p>
                <#if pppRelevant??>
					<b>Related composition:</b>
					<u><@com.documentReferenceMultiple record.GeneralInformation.RelatedCompositions.Composition/></u>
                <#else>
					<u>Related composition: <@com.documentReferenceMultiple record.GeneralInformation.RelatedCompositions.Composition/></u>
                </#if>
			</p>
        </#if>

    <#--NOTE: is this elseif correct? csfRelevant is repeated here...-->
    <#elseif csrRelevant?? || genericRelevant??>

        <#if record.GeneralInformation.NotClassified>
			<p>
				The substance is not classified
			</p>
        <#else>
            <#if !nzEPArelevant??>
				<p>
					The substance is classified as follows:
				</p>
            </#if>
        </#if>
    </#if>

    <#if pppRelevant??>

        <#if record.GeneralInformation.NotClassified>
			<p>
				The substance is not classified
			</p>
        <#else>
			<p><b>Classification</b></p>
			<p>The substance is classified as follows:</p>
        </#if>
    </#if>

    <@com.emptyLine/>
	<@printClassificationForPhysicochemicalPropertiesTable record />

<#-- AICIS only docbook format and data -->
    <#if aicisRelevant??>
		<#-- hard pagebreak -->
		<p><u>
			Australian Regulatory Controls – Human health hazards
		</u></p>

        <#if aicisStatement?has_content>
        <#-- Iterate AICIS statements -->
            <#list aicisStatement as aicisStatements>
                <#if aicisStatements?has_content>
                <#-- Provide only AICIS statement details that relate to the relevant GHS information being outputted -->
                    <#if checkGhsUUIDs(recordList, aicisStatements)>
						<p><@com.richText aicisStatements.SubjectReasonParametersScopeSummaries.SummaryOfHumanHealthHazards /></p>
                    </#if>
                </#if>
            </#list>
        </#if>
    </#if>

	<@printClassificationForHealthHazardsTable record documentNode/>

    <#list record.Classification.SpecificConcentrations.ConcentrationRange as item>
        <#if isNotEmptyConcentrationBlock(item)>

			<p>
				<u>Specific concentration limits:</u>
			</p>

			<table style="width:100%">
				<thead>
				<tr>
					<th style="width:30%"><?dbfo bgcolor="#FBDDA6" ?>
						<b>Concentration (%)</b>
					</th>
					<th style="width:70%"><?dbfo bgcolor="#FBDDA6" ?>
						<b>Classification</b>
					</th>
				</tr>
				</thead>

				<tbody>
				<tr>
					<!-- Concentration (%) -->
					<td>
                        <@com.range item.ConcentrationRangeVal/>
					</td>
					<!-- Classification -->
					<td>
                        <@com.picklistMultiple item.HazardCategories/>
					</td>
				</tr>
				</tbody>
			</table>
        </#if>
    </#list>

	<#--  Acute Toxicity Estimates (ATE)  -->
	<#if record.Classification.ATE?has_content>
		<@com.emptyLine/>
		<p>
			<u>Acute Toxicity Estimates (ATE):</u>
		</p>

		<table style="width:100%">
			<thead>
				<tr>
					<th style="width:33%"><?dbfo bgcolor="#FBDDA6" ?>
						<b>Oral</b>
					</th>
					<th style="width:33%"><?dbfo bgcolor="#FBDDA6" ?>
						<b>Dermal</b>
					</th>
					<th style="width:33%"><?dbfo bgcolor="#FBDDA6" ?>
						<b>Inhalation</b>
					</th>
				</tr>
			</thead>
			
			<tbody>
				<tr>
					<!-- Oral -->
					<td>
						<@com.value record.Classification.ATE.Oral/>
					</td>
					<!-- Dermal -->
					<td>
						<@com.value record.Classification.ATE.Dermal/>
					</td>
					<!-- Inhalation -->
					<td>
						<@com.value record.Classification.ATE.Inhalation/>
					</td>
				</tr>
			</tbody>
		</table>
	</#if>


<#-- AICIS only docbook format and data -->
    <#if aicisRelevant??>
		<?hard-pagebreak?>
		<u>Australian Regulatory Controls – Environmental hazards</u>

        <#if aicisStatement?has_content>
        <#-- Iterate AICIS statements -->
            <#list aicisStatement as aicisStatements>
                <#if aicisStatements?has_content>
                <#-- Provide only AICIS statement details that relate to the relevant GHS information being outputted -->
                    <#if checkGhsUUIDs(recordList, aicisStatements)>
						<p><@com.richText aicisStatements.SubjectReasonParametersScopeSummaries.SummaryOfEnvironmentalHazardCharacteristics/></p>
                    </#if>
                </#if>
            </#list>
        </#if>
    </#if>

	<@printClassificationForEnvironmentalHazards record/>

    <#if nzEPArelevant??>
        <#if record.Classification.AdditionalHazard.Classes?has_content>
            <br/>
			<table border="1">
				<title>Classification according to GHS for additional hazard classes</title>
				<col width="30%"/>
				<col width="70%"/>
				<tbody>
				<tr>
					<!-- Additional hazard classes -->
					<td><?dbfo bgcolor="#FBDDA6" ?>
						Additional hazard classes:
					</td>
					<td>
                        <@com.text record.Classification.AdditionalHazard.Classes/>
					</td>
				</tr>
				</tbody>
			</table>
        </#if>
    <#else>
        <#if (record.Classification.AdditionalHazard.Classes?has_content) && (record.Classification.AdditionalHazard.Statements?has_content)>
            <br/>
			<b>Classification and labelling according to CLP / GHS for additional hazard classes</b>

			<table style="width:100%">
				
				<tbody>
				<tr>
					<!-- Additional hazard classes -->
					<th style="width:30%"><?dbfo bgcolor="#FBDDA6" ?>
						Additional hazard classes:
					</th>
					<td style="width:70%">
                        <@com.text record.Classification.AdditionalHazard.Classes/>
					</td>
				</tr>

				<tr>
					<!-- Additional hazard statements -->
					<th style="width:30%"><?dbfo bgcolor="#FBDDA6" ?>
						Additional hazard statements:
					</th>
					<td style="width:70%">
                        <@com.text record.Classification.AdditionalHazard.Statements/>
					</td>
				</tr>

				</tbody>
			</table>
        </#if>
    </#if>
</#compress>
</#macro>

<#macro printLabellingSection record>
    <#if !nzEPArelevant??>
        <@com.emptyLine/>
		<p><b>Labelling</b></p>

        <#if record.Labelling.SignalWord?has_content>
            <@com.emptyLine/>
			<p>
				Signal word: <@com.picklist record.Labelling.SignalWord/>
			</p>
        </#if>

        <#if record.Labelling.HazardPictogramBlock.HazardPictogram?has_content>
            <@com.emptyLine/>
			<p>
				<u>Hazard pictogram:</u>
                <@com.emptyLine/>
                <@HazardPictogramList record.Labelling.HazardPictogramBlock.HazardPictogram/>
			</p>
        </#if>

        <#if record.Labelling.HazardStatementsBlock.HazardStatements?has_content>
            <@com.emptyLine/>
			<p>
				<u>Hazard statements:</u>
                <@HazardStatementList record.Labelling.HazardStatementsBlock.HazardStatements/>
			</p>
        </#if>

        <#if record.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements?has_content>
            <@com.emptyLine/>
			<p>
				<u>Precautionary statements:</u>
                <@PrecautionaryStatementsList record.Labelling.PrecautionaryStatementsBlock.PrecautionaryStatements/>
			</p>
        </#if>

        <#if record.Labelling.LabelingRequirementsBlock.LabelingRequirements?has_content>
            <@com.emptyLine/>
			<p>
				<u>Additional labelling requirements (CLP supplemental hazard statement):</u>
                <@SupplimentalHazardStatementList record.Labelling.LabelingRequirementsBlock.LabelingRequirements/>
			</p>
        </#if>

        <#if record.Labelling.LabelingRequirementsBlock.AdditionalLabelling?has_content>
            <@com.emptyLine/>
			<p>
				<u>Additional labelling:</u>
                <@AdditionalLabellingList record.Labelling.LabelingRequirementsBlock.AdditionalLabelling/>
			</p>
        </#if>

        <#if record.NotesBlock.Notes?has_content>
            <@com.emptyLine/>
			<p>
				<u>Notes:</u>
                <@NotesLabellingList record.NotesBlock.Notes/>
			</p>
        </#if>

    </#if>
</#macro>

<#macro HazardPictogramList HazardPictogramRepeatableBlock shouldShowPictureWithIndent=true>
<#compress>
	<#if HazardPictogramRepeatableBlock?has_content>
		<#list HazardPictogramRepeatableBlock as blockItem>
			<#if shouldShowPictureWithIndent>
			<#-- indent here -->
			<#else>
			<#-- para here -->
			</#if>

				<@com.picklist blockItem.Code/>
				<#if blockItem.Code.code?has_content>
					<#assign phraseImageMeta = iuclid.getImageMetadataForPhraseCode(blockItem.Code.code) />					
					<#if phraseImageMeta?has_content>
						<#assign phraseImagePrinted = false/> 
						<#if iuclid.imageMimeTypeSupported(phraseImageMeta.mediaType)>
							<#assign phraseImagePrinted = true/> 
								<div class="mediaobject">
									<div class="imageobject">
										<img src="data:${phraseImageMeta.mediaType};base64,${iuclid.getImageContentForPhraseCode(phraseImageMeta.code, phraseImageMeta.mediaType)}" />
									</div>
								</div>
							<@com.emptyLine/>
						</#if>
						<#if !phraseImagePrinted>
							<p><b>The image for phrase code ${blockItem.Code.code} is in an unsupported format!</b></p>
						</#if>
					<#else/>
						<p><b>No image found for phrase code ${blockItem.Code.code}</b></p>
					</#if>
				</#if>				
			<#-- para here -->
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro HazardStatementList HazardStatementRepeatableBlock param="">
<#compress>

	<#if HazardStatementRepeatableBlock?has_content>
		<#list HazardStatementRepeatableBlock as blockItem>

			<#if !spcRelevant??><#-- indent here -->
				<#else>
			</#if>

				<#-- switch off paramterised phrase activation -->
				<#if !(param?has_content) && param!="paramPhrase">
					<@com.picklist blockItem.HazardStatement/>
					<#if blockItem.AdditionalText?has_content && !spcRelevant??>
						(<@com.text blockItem.AdditionalText/>)
					</#if>
				<#-- parameterised phrase -->
				<#elseif param=="paramPhrase" && spcRelevant??>
					${getFilledPhraseText(blockItem.HazardStatement, blockItem.HazardStatement.code, blockItem.AdditionalText)}          
				</#if>
			
			<#if !spcRelevant??><#-- para here --></#if>	

			<#if spcRelevant?? && blockItem_has_next><p></p><#else><p></p></#if>
		</#list>	
	</#if> 	
</#compress>
</#macro>


<#macro PrecautionaryStatementsList PrecautionaryStatementRepeatableBlock param="">
<#compress>
	
	<#if PrecautionaryStatementRepeatableBlock?has_content>
		<#list PrecautionaryStatementRepeatableBlock as blockItem>

			<#if !spcRelevant??><#-- indent -->
				<#else>
			</#if>

				<#-- switch off paramterised phrase activation -->
				<#if !(param?has_content) && param!="paramPhrase">
					<@com.picklist blockItem.PrecautionaryStatement/>
					<#if blockItem.AdditionalText?has_content && !spcRelevant??>
						(<@com.text blockItem.AdditionalText/>)
					</#if>
					<#-- parameterised phrase -->
				<#elseif param=="paramPhrase" && spcRelevant??>
					${getFilledPhraseText(blockItem.PrecautionaryStatement, blockItem.PrecautionaryStatement.code, blockItem.AdditionalText)}          
				</#if>				
			
			<#if !spcRelevant??><#-- para here --></#if>	
			<#if spcRelevant?? && blockItem_has_next><p></p></#if>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro SupplimentalHazardStatementList SupplimentalHazardStatementRepeatableBlock param="">
<#compress>
	<#if SupplimentalHazardStatementRepeatableBlock?has_content>
	
		<#list SupplimentalHazardStatementRepeatableBlock as blockItem>
			<#if blockItem?has_content>	
			
				<#if !spcRelevant??><#-- indent -->
					<#else>
				</#if>

					<#-- switch off paramterised phrase activation -->
					<#if !(param?has_content) && param!="paramPhrase">
						<@com.picklist blockItem.SupplHazardStatement/>
						<#if blockItem.AdditionalText?has_content && !spcRelevant??>
							(<@com.text blockItem.AdditionalText/>)
						</#if>
					<#-- parameterised phrase -->
					<#elseif param=="paramPhrase" && spcRelevant??>
						${getFilledPhraseText(blockItem.SupplHazardStatement, blockItem.SupplHazardStatement.code, blockItem.AdditionalText)}          
					</#if>

				<#if !spcRelevant??><#-- para here --></#if>
				<#if spcRelevant?? && blockItem_has_next><p></p></#if>
			</#if>
		</#list>
		
  	</#if>
</#compress>
</#macro>

<#function getFilledPhraseText statementValue phraseCode parameters>
<#escape x as x?html>

    <#assign filledText = []>
    <#local code = []>

    <#if phraseCode?has_content>
		<#if standardToParameterisedPhraseCode?has_content>
        	<#local customPhraseCode = standardToParameterisedPhraseCode[phraseCode]!"">       	
			<#if customPhraseCode?has_content>
				<#local code = customPhraseCode />
			</#if>
		</#if>
	</#if>

		<#if code?has_content && standardToParameterisedPhraseCode?has_content && languageLocale?has_content && parameters?has_content>
		<#local localizedPhrase = iuclid.localizedPhraseDefinitionFor(code, "${languageLocale}", parameters)>
		<#local filledText><@com.localizedPhrasesMacro localizedPhrase statementValue /></#local>

		<#elseif languageLocale?has_content>		
			<#local localizedPhrase = iuclid.localizedPhraseDefinitionFor(phraseCode, "${languageLocale}")>
			<#local filledText><@com.localizedPhrasesMacro localizedPhrase statementValue /></#local>

		<#else>		
			<#local localizedPhrase = iuclid.localizedPhraseDefinitionFor(phraseCode, "en")>
			<#local filledText><@com.localizedPhrasesMacro localizedPhrase statementValue /></#local>
		</#if>
			
    <#return filledText>
</#escape>
</#function>

<#macro AdditionalLabellingList AdditionalLabellingRepeatableBlock>
<#compress>
	<#if AdditionalLabellingRepeatableBlock?has_content>
		<#list AdditionalLabellingRepeatableBlock as blockItem>
			<#if !spcRelevant??><#-- indent -->
				<#else>
				<p></#if>				
				<@com.text blockItem.Labelling/>
			</p>
		</#list>
  	</#if>
</#compress>
</#macro>

<#macro NotesLabellingList NotesRepeatableBlock>
<#compress>
	<#if NotesRepeatableBlock?has_content>
		<#list NotesRepeatableBlock as blockItem>
			<#-- indent -->
				<@com.picklist blockItem.Note/>
		
		</#list>
  	</#if>
</#compress>
</#macro>

<#function isNotEmptyClassificationBlock block>
	<#if !(block?has_content)>
		<#return false>
	</#if>
	<#if block.HazardCategory?has_content || block.HazardStatement?has_content || block.ReasonForNoClassification?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function isNotEmptyClassificationBlockNZEPA block>
	<#if !(block?has_content)>
		<#return false>
	</#if>
	<#if block.HazardCategory?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function isNotEmptyConcentrationBlock record>
	<#if !(record?has_content)>
		<#return false>
	</#if>
	<#if record.ConcentrationRangeVal?has_content || record.HazardCategories?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#function checkGhsUUIDs recordList aicisStatements>

<#-- get linked GHS document key -->						
<#assign linkedGhsDocument = iuclid.getDocumentForKey(aicisStatements.SubjectReasonParametersScopeSummaries.RelatedGHS)/>
					
<#if recordList?has_content>
	<#list recordList as records>

		<#--compare linked GHS document uuid with GHS document UUID being outputted -->
		<#if linkedGhsDocument?has_content && linkedGhsDocument.documentKey.uuid==records.documentKey.uuid>
			<#return true>
		<#else>
			<#return false>
		</#if>

	</#list>
</#if>
	<#return false>
</#function>

<#macro classificationSubstanceName ghsOrDsdDpdRecord, _subject>
<#compress>
	<#if ghsOrDsdDpdRecord.GeneralInformation.Name?has_content>
	<#assign docUrl=iuclid.webUrl.documentView(ghsOrDsdDpdRecord.documentKey)/>
		<#if docUrl?has_content>
		 <a href="${docUrl}"><@com.text ghsOrDsdDpdRecord.GeneralInformation.Name/></a>
		
	<#else/>
		<@com.substanceName _subject />
		</#if>
  	</#if>
</#compress>
</#macro>

<#macro printClassificationForPhysicochemicalPropertiesTable record>

	<#if nzEPArelevant??>
	<b>Classification according to GHS for physicochemical properties</b>
	<#else>
	<b>Classification and labelling according to CLP / GHS for physicochemical properties</b>
	</#if>

	<table style="width:100%">

		<#if nzEPArelevant??>
		<colgroup>
        <col style="width:20%"/>
        <col style="width:25%"/>
        <col style="width:30%"/>
   		</colgroup>
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
			</tr>
		</thead>
		<#else>
		<colgroup>
        <col style="width:15%"/>
        <col style="width:20%"/>
        <col style="width:25%"/>
        <col style="width:20%"/>
        <col style="width:20%"/>
    	</colgroup>
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for no classification</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for classification</b>
				</th>
			</tr>
		</thead>
		</#if>

		<tbody>

		<#assign classToBlockMap = {
        "Explosives:" : record.Classification.PhysicalHazards.Explosives,
        "Desensitised explosives:" : record.Classification.PhysicalHazards.DesensitizedExplosives,
        "Flammable gases and chemically unstable gases:" : record.Classification.PhysicalHazards.FlammableGases,
        "Aerosols:" : record.Classification.PhysicalHazards.FlammableAerosols,
        "Chemicals under Pressure:" : record.Classification.PhysicalHazards.ChemicalsUnderPressure,
        "Oxidising gases:" : record.Classification.PhysicalHazards.OxidisingGases,
        "Gases under pressure:" : record.Classification.PhysicalHazards.GasesPres,
        "Flammable liquids:" : record.Classification.PhysicalHazards.FlammableLiquids,
        "Flammable solids:" : record.Classification.PhysicalHazards.FlammableSolids,
        "Self-reactive substances and mixtures:" : record.Classification.PhysicalHazards.SelfReactiveSubstMixt,
        "Pyrophoric liquids:" : record.Classification.PhysicalHazards.PyrophoricLiquids,
        "Pyrophoric solids:" : record.Classification.PhysicalHazards.PyrophoricSolids,
        "Self-heating substances and mixtures:" : record.Classification.PhysicalHazards.SelfHeatSubstMixt,
        "Substances and mixtures which in contact with water emit flammable gases:" : record.Classification.PhysicalHazards.SubstMixtWater,
        "Oxidising liquids:" : record.Classification.PhysicalHazards.OxidisingLiquids,
        "Oxidising solids:" : record.Classification.PhysicalHazards.OxidisingSolids,
        "Organic peroxides:" : record.Classification.PhysicalHazards.OrganicPeroxides,
        "Corrosive to metals:" : record.Classification.PhysicalHazards.CorMetals
        }/>
        <#assign hazardClasses = classToBlockMap?keys />

        <#list hazardClasses as hazardClass>
            <#assign block = classToBlockMap[hazardClass] />
            <#if nzEPArelevant??>
                <#if isNotEmptyClassificationBlockNZEPA(block)>
					<tr>
						<!-- Hazard class -->
						<td>
                            ${hazardClass!}
						</td>
						<!-- Hazard category -->
						<td>
                            <@com.picklist block.HazardCategory/>
						</td>
						<!-- Hazard statement -->
						<td>
                            <@com.picklist block.HazardStatement/>
						</td>
					</tr>
                </#if>
            <#else>
                <#if isNotEmptyClassificationBlock(block)>
					<tr>
						<!-- Hazard class -->
						<td>
                            ${hazardClass!}
						</td>
						<!-- Hazard category -->
						<td>
                            <@com.picklist block.HazardCategory/>
						</td>
						<!-- Hazard statement -->
						<td>
                            <@com.picklist block.HazardStatement/>
						</td>
						<!-- Reason for no classification -->
						<td>
                            <@com.picklist block.ReasonForNoClassification/>
						</td>
						<!-- Reason for classification -->
						<td>
                            <@com.picklistMultiple block.ReasonForClassification/>
						</td>
					</tr>
                </#if>
            </#if>
        </#list>
		</tbody>
	</table>
</#macro>

<#macro printClassificationForHealthHazardsTable record documentNode="">
<#compress>
	<br/>

	<#if nzEPArelevant??>
	<b>Classification according to GHS for health hazards</b>
	<#else>
	<b>Classification and labelling according to CLP / GHS for health hazards</b>
	</#if>

	<table style="width:100%">

		<#if nzEPArelevant??>
		<colgroup>
        <col style="width:20%"/>
		<col style="width:25%"/>
		<col style="width:30%"/>
   		</colgroup>
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th> <?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
			</tr>
		</thead>
		<#else>
		<colgroup>
		<col style="width:15%"/>
        <col style="width:20%"/>
        <col style="width:25%"/>
        <col style="width:20%"/>
        <col style="width:20%"/>
    	</colgroup>		
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for no classification</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for classification</b>
				</th>
			</tr>
		</thead>
		</#if>		

        <#assign classToBlockMap = {
        "Acute toxicity - oral:" : record.Classification.HealthHazards.AcuteToxicityOral,
        "Acute toxicity - dermal:" : record.Classification.HealthHazards.AcuteToxicityDermal,
        "Acute toxicity - inhalation:" : record.Classification.HealthHazards.AcuteToxicityInhalation,
        "Skin corrosion / irritation:" : record.Classification.HealthHazards.Irritation,
        "Serious damage / eye irritation:" : record.Classification.HealthHazards.EyeIrritation,
        "Respiratory sensitisation:" : record.Classification.HealthHazards.RespiratorySensitisation,
        "Skin sensitisation:" : record.Classification.HealthHazards.SkinSensitisation,
        "Aspiration hazard:" : record.Classification.HealthHazards.AspirationHazard,
        "Reproductive Toxicity:" : record.Classification.HealthHazards.ReproductiveToxicity.ReproductiveToxicity,
        "Reproductive Toxicity: Effects on or via lactation:" : record.Classification.HealthHazards.ReproductiveToxicity.Effects,
        "Germ cell mutagenicity:" : record.Classification.HealthHazards.GermCell.GermCell,
        "Carcinogenicity:" : record.Classification.HealthHazards.Carcinogenicity.Carcinogenicity
        }/>
        <#assign hazardClasses = classToBlockMap?keys />

		<tbody>
        <#list hazardClasses as hazardClass>
            <#assign block = classToBlockMap[hazardClass] />
            <#if nzEPArelevant??>
                <#if isNotEmptyClassificationBlockNZEPA(block)>
					<tr>
						<!-- Hazard class -->
						<td>
                            ${hazardClass!}
						</td>
						<!-- Hazard category -->
						<td>
                            <@com.picklist block.HazardCategory/>
                            <#if block.hasElement("SpecificEffect") && block.SpecificEffect?has_content>
								<p>Specific effect: <@com.text block.SpecificEffect/></p>
                            </#if>
                            <#if block.hasElement("RouteExposure") && block.RouteExposure?has_content>
								<p>Route of exposure: <@com.picklistMultiple block.RouteExposure/></p>
                            </#if>
						</td>
						<!-- Hazard statement -->
						<td>
                            <@com.picklist block.HazardStatement/>
						</td>
					</tr>
                </#if>
            <#else>
                <#if isNotEmptyClassificationBlock(block)>
					<tr>
						<#-- Hazard class -->
						<td>
                            ${hazardClass!}
						</td>
						<#-- Hazard category -->
						<td>
                            <@com.picklist block.HazardCategory/>
                            <#if block.hasElement("SpecificEffect") && block.SpecificEffect?has_content>
								<p>Specific effect: <br/>
								<@com.text block.SpecificEffect/></p>
                            </#if>
                            <#if block.hasElement("RouteExposure") && block.RouteExposure?has_content>
								<p>Route of exposure: <br/>
								<@com.picklistMultiple block.RouteExposure/></p>
                            </#if>
						</td>

						<#-- Hazard statement -->
						<td><@com.picklist block.HazardStatement/></td>

						<#-- Reason for no classification -->
						<td>						
						<@com.picklist block.ReasonForNoClassification/>
						<@com.emptyLine/>
						<#if ghsRelevant?? && block.ReasonForNoClassification?has_content>
						<#assign justificationClassification><@reasonForClassificationOrNoClassification documentNode "${hazardClass}"/></#assign>
						${justificationClassification}
						</#if>
						</td>

						<#-- Reason for classification -->
						<td>						
						<@com.picklistMultiple block.ReasonForClassification/>
						<@com.emptyLine/>
						<#if ghsRelevant?? && block.ReasonForClassification?has_content>
						<#assign justificationClassification><@reasonForClassificationOrNoClassification documentNode "${hazardClass}"/></#assign>
						${justificationClassification}
						</#if>
						</td>
					</tr>
                </#if>
            </#if>
        </#list>

        <#list record.Classification.HealthHazards.ToxicitySingle.Toxicity as item>
			<tr>
				<!-- Hazard class -->               
				<td>Specific target organ toxicity – single exposure:</td>
                  
				<!-- Hazard category -->
				<td>
					<p><@com.picklist item.Toxicity.HazardCategory/></p>
					<#if item.Toxicity.AffectedOrgans?has_content>
					<p>Affected organs:</p>
						<@com.picklistMultiple item.Toxicity.AffectedOrgans/>
                    </#if>

					<#if item.Toxicity.RouteExposure?has_content>
					<p>Route of exposure:</p>
						<@com.picklistMultiple item.Toxicity.RouteExposure/>
                    </#if>
				</td>
				<!-- Hazard statement -->
				<td><@com.picklist item.Toxicity.HazardStatement/></td>
				<!-- Reason for no classification -->
                <#if !nzEPArelevant??>
					<td><@com.picklist item.Toxicity.ReasonForNoClassification/></td>
					<!-- Reason for classification -->
					<td><@com.picklistMultiple item.Toxicity.ReasonForClassification/></td>
                </#if>
			</tr>
        </#list>

        <#list record.Classification.HealthHazards.ToxicityRepeated.Toxicity as item>
			<tr>
				<!-- Hazard class -->         
				<td>Specific target organ toxicity – repeated exposure:</td>
              
      			<!-- Hazard category -->
				<td>
					<p><@com.picklist item.Toxicity.HazardCategory/></p>
					<p><#if item.Toxicity.AffectedOrgans?has_content>
							Affected organs: <br/>
							<@com.picklistMultiple item.Toxicity.AffectedOrgans/>
                        </#if></p>
					<p><#if item.Toxicity.RouteExposure?has_content>
							Route of exposure:  <br/>
							<@com.picklistMultiple item.Toxicity.RouteExposure/>
                        </#if></p>
				</td>
				<!-- Hazard statement -->
				<td><@com.picklist item.Toxicity.HazardStatement/></td>
				<!-- Reason for no classification -->
                <#if !nzEPArelevant??>
					<td><@com.picklist item.Toxicity.ReasonForNoClassification/></td>
					<!-- Reason for classification -->
					<td><@com.picklistMultiple item.Toxicity.ReasonForClassification/></td>
                </#if>
			</tr>
        </#list>
		</tbody>
	</table>
</#compress>
</#macro>

<#macro reasonForClassificationOrNoClassification documentNode hazardClass="">
<#list documentNode as doc>
	<#if hazardClass=="Reproductive Toxicity:" || hazardClass=="Reproductive Toxicity: Effects on or via lactation:">
		<#if doc.documentSubType=="ToxicityToReproduction">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "JustificationForClassificationOrNonClassification"/>
		</#if>

	<#elseif hazardClass=="Germ cell mutagenicity:" && doc.documentSubType=="GeneticToxicity">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "Remarks"/>

	<#elseif hazardClass=="Carcinogenicity:" && doc.documentSubType=="Carcinogenicity">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "JustifClassifCarc"/>

	<#elseif hazardClass=="Respiratory sensitisation:" || hazardClass=="Skin sensitisation:">
		<#if doc.documentSubType=="Sensitisation">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "Remarks"/>
		</#if>

	<#elseif hazardClass=="Serious damage / eye irritation:" || hazardClass=="Skin corrosion / irritation:">
		<#if doc.documentSubType=="IrritationCorrosion">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "Remarks"/>
		</#if>

	<#elseif hazardClass=="Acute toxicity - oral:" || hazardClass=="Acute toxicity - dermal:" || hazardClass=="Acute toxicity - inhalation:">
		<#if doc.documentSubType=="AcuteToxicity">
		<@keyHumanHealthHazardAssessmentInformation.justification doc "JustifClassifAcuteTox"/>		
		</#if>
		
	</#if>
</#list>
</#macro>

<#macro printClassificationForEnvironmentalHazards record>

	<br/>

	<#if nzEPArelevant??>
	<title><b>Classification according to GHS for environmental hazards</b></title>
	<#else>
	<title><b>Classification and labelling according to CLP / GHS for environmental hazards</b></title>
	</#if>

		<table style="width:100%">

		<#if nzEPArelevant??>
		<colgroup>
        <col style="width:24%"/>
        <col style="width:21%"/>
        <col style="width:30%"/>
   		</colgroup>
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
			</tr>
		</thead>

        <#else>
		<colgroup>
        <col style="width:19%"/>
        <col style="width:16%"/>
        <col style="width:25%"/>
		<col style="width:20%"/>
		<col style="width:20%"/>
   		</colgroup>
		<thead>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard class</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard category</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Hazard statement</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for no classification</b>
				</th>
				<th><?dbfo bgcolor="#FBDDA6" ?>
					<b>Reason for classification</b>
				</th>
			</tr>
		</thead>

        </#if>

		<tbody>
       
        <#if nzEPArelevant??>
            <#if isNotEmptyClassificationBlockNZEPA(record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm)>
				<tr>
					<!-- Hazard class -->
					<td>
						Hazards to the aquatic environment (acute/short-term):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardStatement/>
					</td>
				</tr>
            </#if>
        <#else>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm)>
				<tr>
					<!-- Hazard class -->
					<td>
						Hazards to the aquatic environment (acute/short-term):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.AquaticEnvironment.AcuteShortTerm.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>

        <#if nzEPArelevant??>
            <#if isNotEmptyClassificationBlockNZEPA(record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm)>
				<tr>
					<!-- Hazard class -->
					<td>
						Hazards to the aquatic environment (chronic/long-term):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardStatement/>
					</td>
				</tr>
            </#if>
        <#else>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm)>
				<tr>
					<!-- Hazard class -->
					<td>
						Hazards to the aquatic environment (chronic/long-term):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.AquaticEnvironment.LongTerm.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>

		<!-- M-Factor acute -->
        <#if nzEPArelevant??>
            <#if record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorAcute?has_content>
				<tr>
					<td colspan="3">
						M-Factor
						acute: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorAcute/>
					</td>
				</tr>
            </#if>

        <#else>
			<tr>
				<td colspan="5">
					M-Factor
					acute: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorAcute/>
				</td>
			</tr>
        </#if>

		<!-- M-Factor chronic -->
        <#if nzEPArelevant??>
            <#if record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorChronic?has_content>
				<tr>
					<td colspan="3">
						M-Factor
						chronic: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorChronic/>
					</td>
				</tr>
            </#if>

        <#else>
			<tr>
				<td colspan="5">
					M-Factor
					chronic: <@com.number record.Classification.EnvironmentalHazards.AquaticEnvironment.MFactor.MFactorChronic/>
				</td>
			</tr>
        </#if>

        <#if !nzEPArelevant??>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone)>
				<tr>
					<!-- Hazard class -->
					<td>
						Hazardous to the ozone layer:
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.OzoneLayer.HazardousOzone.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>

		<#if nzEPArelevant??>
            <#if isNotEmptyClassificationBlockNZEPA(record.Classification.EnvironmentalHazards.EDENV)>
				<tr>
					<!-- Hazard class -->
					<td>
						Endocrine disruption for the environment (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.EDENV.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.EDENV.HazardStatement/>
					</td>
				</tr>
            </#if>
        <#else>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.EDENV)>
				<tr>
					<!-- Hazard class -->
					<td>
						Endocrine disruption for the environment (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.EDENV.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.EDENV.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.EDENV.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.EDENV.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>

		<#if nzEPArelevant??>
            <#if isNotEmptyClassificationBlockNZEPA(record.Classification.EnvironmentalHazards.PBT)>
				<tr>
					<!-- Hazard class -->
					<td>
						Persistent, Bioaccumulative and Toxic or Very Persistent, Very Bioaccumulative properties (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PBT.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PBT.HazardStatement/>
					</td>
				</tr>
            </#if>
        <#else>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.PBT)>
				<tr>
					<!-- Hazard class -->
					<td>
						Persistent, Bioaccumulative and Toxic or Very Persistent, Very Bioaccumulative properties (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PBT.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PBT.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PBT.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.PBT.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>

		<#if nzEPArelevant??>
            <#if isNotEmptyClassificationBlockNZEPA(record.Classification.EnvironmentalHazards.PMT)>
				<tr>
					<!-- Hazard class -->
					<td>
						Persistent, Mobile and Toxic or Very Persistent, Very Mobile properties (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PMT.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PMT.HazardStatement/>
					</td>
				</tr>
            </#if>
        <#else>
            <#if isNotEmptyClassificationBlock(record.Classification.EnvironmentalHazards.PMT)>
				<tr>
					<!-- Hazard class -->
					<td>
						Persistent, Mobile and Toxic or Very Persistent, Very Mobile properties (EU CLP):
					</td>
					<!-- Hazard category -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PMT.HazardCategory/>
					</td>
					<!-- Hazard statement -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PMT.HazardStatement/>
					</td>
					<!-- Reason for no classification -->
					<td>
                        <@com.picklist record.Classification.EnvironmentalHazards.PMT.ReasonForNoClassification/>
					</td>
					<!-- Reason for classification -->
					<td>
                        <@com.picklistMultiple record.Classification.EnvironmentalHazards.PMT.ReasonForClassification/>
					</td>
				</tr>
            </#if>
        </#if>
		</tbody>
	</table>
</#macro>

<#function isComposite doc>
<#return doc.documentType == "MIXTURE" || doc.documentType == "SUBSTANCE" || doc.documentType == "TEMPLATE">
</#function>
 <h2 id="link">Content to reference</h2>
